@@ -802,6 +802,11 @@ on_location_changed (GtkSourceFile *file,
 
 			g_error_free (error);
 		}
+
+		if (priv->metadata_info == NULL)
+		{
+			priv->metadata_info = g_file_info_new ();
+		}
 	}
 }
 
@@ -832,6 +837,7 @@ gedit_document_init (GeditDocument *doc)
 	g_get_current_time (&priv->time_of_last_save_or_load);
 
 	priv->file = gtk_source_file_new ();
+	priv->metadata_info = g_file_info_new ();
 
 	g_signal_connect_object (priv->file,
 				 "notify::location",
@@ -1660,23 +1666,15 @@ get_metadata_from_gvfs (GeditDocument *doc,
 }
 
 static void
-set_gvfs_metadata (GeditDocument *doc,
-		   GFileInfo     *info,
-		   const gchar   *key,
-		   const gchar   *value)
+set_gvfs_metadata (GFileInfo   *info,
+		   const gchar *key,
+		   const gchar *value)
 {
-	GeditDocumentPrivate *priv;
-
-	priv = gedit_document_get_instance_private (doc);
+	g_return_if_fail (G_IS_FILE_INFO (info));
 
 	if (value != NULL)
 	{
 		g_file_info_set_attribute_string (info, key, value);
-
-		if (priv->metadata_info != NULL)
-		{
-			g_file_info_set_attribute_string (priv->metadata_info, key, value);
-		}
 	}
 	else
 	{
@@ -1685,14 +1683,6 @@ set_gvfs_metadata (GeditDocument *doc,
 					   key,
 					   G_FILE_ATTRIBUTE_TYPE_INVALID,
 					   NULL);
-
-		if (priv->metadata_info != NULL)
-		{
-			g_file_info_set_attribute (priv->metadata_info,
-						   key,
-						   G_FILE_ATTRIBUTE_TYPE_INVALID,
-						   NULL);
-		}
 	}
 }
 
@@ -1774,8 +1764,8 @@ gedit_document_set_metadata (GeditDocument *doc,
 
 		if (priv->use_gvfs_metadata)
 		{
-			/* Collect the metadata into @info. */
-			set_gvfs_metadata (doc, info, key, value);
+			set_gvfs_metadata (info, key, value);
+			set_gvfs_metadata (priv->metadata_info, key, value);
 		}
 		else
 		{
