@@ -51,6 +51,11 @@ struct _GeditOpenDocumentSelector
 	GtkWidget *placeholder_box;
 	GtkWidget *scrolled_window;
 
+	GdkRGBA name_label_color;
+	gdouble name_font_size;
+	GdkRGBA path_label_color;
+	gdouble path_font_size;
+
 	GeditOpenDocumentSelectorStore *selector_store;
 	GList *recent_items;
 	GList *home_dir_items;
@@ -380,6 +385,7 @@ fileitem_setup (FileItem *item)
 {
 	gchar *scheme;
 	gchar *filename;
+	gchar *normalized_filename;
 	gchar *candidate = NULL;
 	gchar *path;
 	gchar *name;
@@ -398,8 +404,11 @@ fileitem_setup (FileItem *item)
 			item->name = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
 			g_free (name);
 
-			candidate = g_utf8_strdown (filename, -1);
+			normalized_filename = g_utf8_normalize (filename, -1, G_NORMALIZE_ALL);
 			g_free (filename);
+
+			candidate = g_utf8_casefold (normalized_filename, -1);
+			g_free (normalized_filename);
 		}
 	}
 
@@ -622,7 +631,7 @@ on_entry_changed (GtkEntry                  *entry,
 
 	entry_text = gtk_entry_get_text (entry);
 	gedit_open_document_selector_store_set_recent_filter (selector->selector_store,
-	                                                      g_utf8_strdown (entry_text, -1));
+	                                                      entry_text);
 
 	if (gtk_widget_get_mapped ( GTK_WIDGET (selector)))
 	{
@@ -981,6 +990,7 @@ on_treeview_allocate (GtkWidget                 *widget,
 {
 	GeditOpenDocumentSelectorStore *selector_store;
 	GtkStyleContext *context;
+	GtkStateFlags state;
 	gint name_renderer_natural_size;
 	gint path_renderer_natural_size;
 	GtkBorder padding;
@@ -994,6 +1004,7 @@ on_treeview_allocate (GtkWidget                 *widget,
 	selector_store = selector->selector_store;
 
 	context = gtk_widget_get_style_context (selector->treeview);
+	state = gtk_style_context_get_state (context);
 
 	/* Treeview height computation */
 	gtk_cell_renderer_get_preferred_height (selector->name_renderer,
@@ -1006,7 +1017,7 @@ on_treeview_allocate (GtkWidget                 *widget,
 	                                        NULL,
 	                                        &path_renderer_natural_size);
 
-	gtk_style_context_get_padding (context, GTK_STATE_FLAG_NORMAL, &padding);
+	gtk_style_context_get_padding (context, state, &padding);
 	gtk_cell_renderer_get_padding (selector->name_renderer, NULL, &ypad);
 	gtk_widget_style_get (selector->treeview, "grid-line-width", &grid_line_width, NULL);
 
@@ -1028,6 +1039,31 @@ on_treeview_allocate (GtkWidget                 *widget,
 	gtk_widget_set_size_request (selector->placeholder_box, -1, treeview_height);
 }
 
+static void
+on_treeview_style_updated (GtkWidget                 *widget,
+                           GeditOpenDocumentSelector *selector)
+{
+	GtkStyleContext *context;
+	GtkStateFlags state;
+
+	context = gtk_widget_get_style_context (widget);
+	state = gtk_style_context_get_state (context);
+
+	/* Name label foreground and font size styling */
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "open-document-selector-name-label");
+	gtk_style_context_get_color (context, state, &selector->name_label_color);
+	gtk_style_context_get (context, state, "font-size", &selector->name_font_size, NULL);
+	gtk_style_context_restore (context);
+
+	/* Path label foreground and font size styling */
+	gtk_style_context_save (context);
+	gtk_style_context_add_class (context, "open-document-selector-path-label");
+	gtk_style_context_get_color (context, state, &selector->path_label_color);
+	gtk_style_context_get (context, state, "font-size", &selector->path_font_size, NULL);
+	gtk_style_context_restore (context);
+}
+
 static void
 name_renderer_datafunc (GtkTreeViewColumn         *column,
                         GtkCellRenderer           *name_renderer,
@@ -1035,22 +1071,8 @@ name_renderer_datafunc (GtkTreeViewColumn         *column,
                         GtkTreeIter               *iter,
                         GeditOpenDocumentSelector *selector)
 {
-	GtkStyleContext *context;
-	GdkRGBA label_color;
-	gdouble font_size;
-
-	context = gtk_widget_get_style_context (selector->treeview);
-
-	/* Name label foreground and font size styling */
-	gtk_style_context_add_class (context, "open-document-selector-name-label");
-
-	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &label_color);
-	g_object_set (selector->name_renderer, "foreground-rgba", &label_color, NULL);
-
-	gtk_style_context_get (context, GTK_STATE_FLAG_NORMAL, "font-size", &font_size, NULL);
-	g_object_set (selector->name_renderer, "size-points", font_size, NULL);
-
-	gtk_style_context_remove_class (context, "open-document-selector-name-label");
+	g_object_set (selector->name_renderer, "foreground-rgba", &selector->name_label_color, NULL);
+	g_object_set (selector->name_renderer, "size-points", selector->name_font_size, NULL);
 }
 
 static void
@@ -1060,22 +1082,8 @@ path_renderer_datafunc (GtkTreeViewColumn         *column,
                         GtkTreeIter               *iter,
                         GeditOpenDocumentSelector *selector)
 {
-	GtkStyleContext *context;
-	GdkRGBA label_color;
-	gdouble font_size;
-
-	context = gtk_widget_get_style_context (selector->treeview);
-
-	/* Path label foreground and font size styling */
-	gtk_style_context_add_class (context, "open-document-selector-path-label");
-
-	gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &label_color);
-	g_object_set (selector->path_renderer, "foreground-rgba", &label_color, NULL);
-
-	gtk_style_context_get (context, GTK_STATE_FLAG_NORMAL, "font-size", &font_size, NULL);
-	g_object_set (selector->path_renderer, "size-points", font_size, NULL);
-
-	gtk_style_context_remove_class (context, "open-document-selector-path-label");
+	g_object_set (selector->path_renderer, "foreground-rgba", &selector->path_label_color, NULL);
+	g_object_set (selector->path_renderer, "size-points", selector->path_font_size, NULL);
 }
 
 static void
@@ -1159,6 +1167,11 @@ gedit_open_document_selector_init (GeditOpenDocumentSelector *selector)
 	                  "key-press-event",
 	                  G_CALLBACK (on_treeview_key_press),
 	                  selector);
+
+	g_signal_connect (selector->treeview,
+	                  "style-updated",
+	                  G_CALLBACK (on_treeview_style_updated),
+	                  selector);
 }
 
 GeditOpenDocumentSelector *
